@@ -2,7 +2,7 @@ import { Command } from 'commander';
 import { promises as fs } from 'fs';
 import { log } from '@tamanu/shared/services/logging';
 
-import { Signer } from '@tamanu/shared/models';
+import { Signer } from '@tamanu/database';
 
 import { initDatabase } from '../database';
 
